# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.list_web_auth_n_enrollment_response import ListWebAuthNEnrollmentResponse  # noqa: E501
from agilicus_api.rest import ApiException

class TestListWebAuthNEnrollmentResponse(unittest.TestCase):
    """ListWebAuthNEnrollmentResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ListWebAuthNEnrollmentResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.list_web_auth_n_enrollment_response.ListWebAuthNEnrollmentResponse()  # noqa: E501
        if include_optional :
            return ListWebAuthNEnrollmentResponse(
                webauthn = [
                    agilicus_api.models.web_auth_n_enrollment.WebAuthNEnrollment(
                        metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                        spec = agilicus_api.models.web_auth_n_enrollment_spec.WebAuthNEnrollmentSpec(
                            user_id = '123', 
                            relying_party_id = '123', 
                            attestation_format = 'platform', 
                            attestation_conveyance = 'direct', 
                            user_verification = 'discouraged', ), 
                        status = agilicus_api.models.web_auth_n_enrollment_status.WebAuthNEnrollmentStatus(
                            challenge = 'asdas43ADlaksda8739asfoafsalkasjd', 
                            credential_id = 'YQ==', 
                            transports = [
                                'ble'
                                ], ), )
                    ], 
                limit = 56
            )
        else :
            return ListWebAuthNEnrollmentResponse(
                limit = 56,
        )

    def testListWebAuthNEnrollmentResponse(self):
        """Test ListWebAuthNEnrollmentResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.oidc_proxy_header import OIDCProxyHeader  # noqa: E501
from agilicus_api.rest import ApiException

class TestOIDCProxyHeader(unittest.TestCase):
    """OIDCProxyHeader unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OIDCProxyHeader
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.oidc_proxy_header.OIDCProxyHeader()  # noqa: E501
        if include_optional :
            return OIDCProxyHeader(
                domain_substitution = agilicus_api.models.oidc_proxy_domain_substitution.OIDCProxyDomainSubstitution(
                    standard_headers = agilicus_api.models.oidc_proxy_standard_header.OIDCProxyStandardHeader(
                        location = True, 
                        origin = True, 
                        host = True, ), 
                    other_headers = [
                        agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                            name = 'Accept-Encoding', 
                            value = '*', )
                        ], ), 
                header_overrides = agilicus_api.models.oidc_proxy_header_override.OIDCProxyHeaderOverride(
                    request = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(
                        set = [
                            agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                name = 'Accept-Encoding', 
                                value = '*', )
                            ], 
                        add = [
                            agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                name = 'Accept-Encoding', 
                                value = '*', )
                            ], 
                        remove = [
                            agilicus_api.models.oidc_proxy_header_name.OIDCProxyHeaderName(
                                name = '0', )
                            ], ), 
                    response = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(), )
            )
        else :
            return OIDCProxyHeader(
        )

    def testOIDCProxyHeader(self):
        """Test OIDCProxyHeader"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class SecureAgentSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'org_id': 'str',
        'application_service_ids': 'list[str]',
        'connectors': 'list[SecureAgentConnector]'
    }

    attribute_map = {
        'name': 'name',
        'org_id': 'org_id',
        'application_service_ids': 'application_service_ids',
        'connectors': 'connectors'
    }

    def __init__(self, name=None, org_id=None, application_service_ids=None, connectors=None, local_vars_configuration=None):  # noqa: E501
        """SecureAgentSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._org_id = None
        self._application_service_ids = None
        self._connectors = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.org_id = org_id
        if application_service_ids is not None:
            self.application_service_ids = application_service_ids
        if connectors is not None:
            self.connectors = connectors

    @property
    def name(self):
        """Gets the name of this SecureAgentSpec.  # noqa: E501

        A descriptive name for the secure agent  # noqa: E501

        :return: The name of this SecureAgentSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SecureAgentSpec.

        A descriptive name for the secure agent  # noqa: E501

        :param name: The name of this SecureAgentSpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def org_id(self):
        """Gets the org_id of this SecureAgentSpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this SecureAgentSpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this SecureAgentSpec.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this SecureAgentSpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def application_service_ids(self):
        """Gets the application_service_ids of this SecureAgentSpec.  # noqa: E501

        The list of application service ids associated with this secure agent  # noqa: E501

        :return: The application_service_ids of this SecureAgentSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._application_service_ids

    @application_service_ids.setter
    def application_service_ids(self, application_service_ids):
        """Sets the application_service_ids of this SecureAgentSpec.

        The list of application service ids associated with this secure agent  # noqa: E501

        :param application_service_ids: The application_service_ids of this SecureAgentSpec.  # noqa: E501
        :type: list[str]
        """

        self._application_service_ids = application_service_ids

    @property
    def connectors(self):
        """Gets the connectors of this SecureAgentSpec.  # noqa: E501

        The list of connectors this agent uses to establish tunnels with the infrastructure   # noqa: E501

        :return: The connectors of this SecureAgentSpec.  # noqa: E501
        :rtype: list[SecureAgentConnector]
        """
        return self._connectors

    @connectors.setter
    def connectors(self, connectors):
        """Sets the connectors of this SecureAgentSpec.

        The list of connectors this agent uses to establish tunnels with the infrastructure   # noqa: E501

        :param connectors: The connectors of this SecureAgentSpec.  # noqa: E501
        :type: list[SecureAgentConnector]
        """

        self._connectors = connectors

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecureAgentSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SecureAgentSpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.policy_api import PolicyApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestPolicyApi(unittest.TestCase):
    """PolicyApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.policy_api.PolicyApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_challenge_decision(self):
        """Test case for get_challenge_decision

        evaluate a policy challenge decision  # noqa: E501
        """
        pass

    def test_get_enrollment_decision(self):
        """Test case for get_enrollment_decision

        evaluate a policy enrollment decision  # noqa: E501
        """
        pass

    def test_map_attributes(self):
        """Test case for map_attributes

        map attributes of a user  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.map_attributes_question_input import MapAttributesQuestionInput  # noqa: E501
from agilicus_api.rest import ApiException

class TestMapAttributesQuestionInput(unittest.TestCase):
    """MapAttributesQuestionInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MapAttributesQuestionInput
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.map_attributes_question_input.MapAttributesQuestionInput()  # noqa: E501
        if include_optional :
            return MapAttributesQuestionInput(
                login_info = agilicus_api.models.map_attributes_question_login_info.MapAttributesQuestionLoginInfo(
                    user_object = agilicus_api.models.user_summary.UserSummary(
                        id = '123', 
                        external_id = '123', 
                        enabled = False, 
                        status = 'active', 
                        first_name = 'Alice', 
                        last_name = 'Kim', 
                        email = 'foo@example.com', 
                        provider = 'Google', 
                        roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                        org_id = '123', 
                        created = '2015-07-07T15:49:51.230+02:00', 
                        updated = '2015-07-07T15:49:51.230+02:00', 
                        auto_created = True, 
                        upstream_user_identities = [
                            agilicus_api.models.upstream_user_identity.UpstreamUserIdentity(
                                metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                                spec = agilicus_api.models.upstream_user_identity_spec.UpstreamUserIdentitySpec(
                                    upstream_user_id = 'aa-bb-cc-11-22-33', 
                                    upstream_idp_id = 'https://auth.cloud.egov.city', 
                                    local_user_id = 'tuU7smH86zAXMl76sua6xQ', ), )
                            ], 
                        cascade = True, ), 
                    client_guid = 'absjfladasdf23', 
                    issuer_guid = 'absjfladasdf23', )
            )
        else :
            return MapAttributesQuestionInput(
                login_info = agilicus_api.models.map_attributes_question_login_info.MapAttributesQuestionLoginInfo(
                    user_object = agilicus_api.models.user_summary.UserSummary(
                        id = '123', 
                        external_id = '123', 
                        enabled = False, 
                        status = 'active', 
                        first_name = 'Alice', 
                        last_name = 'Kim', 
                        email = 'foo@example.com', 
                        provider = 'Google', 
                        roles = {"app-1":["viewer"],"app-2":["owner"]}, 
                        org_id = '123', 
                        created = '2015-07-07T15:49:51.230+02:00', 
                        updated = '2015-07-07T15:49:51.230+02:00', 
                        auto_created = True, 
                        upstream_user_identities = [
                            agilicus_api.models.upstream_user_identity.UpstreamUserIdentity(
                                metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                                spec = agilicus_api.models.upstream_user_identity_spec.UpstreamUserIdentitySpec(
                                    upstream_user_id = 'aa-bb-cc-11-22-33', 
                                    upstream_idp_id = 'https://auth.cloud.egov.city', 
                                    local_user_id = 'tuU7smH86zAXMl76sua6xQ', ), )
                            ], 
                        cascade = True, ), 
                    client_guid = 'absjfladasdf23', 
                    issuer_guid = 'absjfladasdf23', ),
        )

    def testMapAttributesQuestionInput(self):
        """Test MapAttributesQuestionInput"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class PolicyCondition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'condition_type': 'str',
        'inverted': 'bool',
        'input_is_list': 'bool',
        'value': 'str',
        'operator': 'str',
        'field': 'str',
        'created': 'datetime',
        'updated': 'datetime'
    }

    attribute_map = {
        'condition_type': 'condition_type',
        'inverted': 'inverted',
        'input_is_list': 'input_is_list',
        'value': 'value',
        'operator': 'operator',
        'field': 'field',
        'created': 'created',
        'updated': 'updated'
    }

    def __init__(self, condition_type=None, inverted=False, input_is_list=False, value=None, operator=None, field=None, created=None, updated=None, local_vars_configuration=None):  # noqa: E501
        """PolicyCondition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._condition_type = None
        self._inverted = None
        self._input_is_list = None
        self._value = None
        self._operator = None
        self._field = None
        self._created = None
        self._updated = None
        self.discriminator = None

        self.condition_type = condition_type
        if inverted is not None:
            self.inverted = inverted
        if input_is_list is not None:
            self.input_is_list = input_is_list
        self.value = value
        self.operator = operator
        if field is not None:
            self.field = field
        if created is not None:
            self.created = created
        if updated is not None:
            self.updated = updated

    @property
    def condition_type(self):
        """Gets the condition_type of this PolicyCondition.  # noqa: E501

        The type of this condition. The type determines how the value will be evaluated. This parameter is case sensitive.  # noqa: E501

        :return: The condition_type of this PolicyCondition.  # noqa: E501
        :rtype: str
        """
        return self._condition_type

    @condition_type.setter
    def condition_type(self, condition_type):
        """Sets the condition_type of this PolicyCondition.

        The type of this condition. The type determines how the value will be evaluated. This parameter is case sensitive.  # noqa: E501

        :param condition_type: The condition_type of this PolicyCondition.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and condition_type is None:  # noqa: E501
            raise ValueError("Invalid value for `condition_type`, must not be `None`")  # noqa: E501
        allowed_values = ["type_client_id_list", "type_org_id_list", "type_user_id_list", "type_upstream_idp_list", "type_ip_in_cidr_list", "type_last_successful_mfa", "type_object_attribute"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and condition_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `condition_type` ({0}), must be one of {1}"  # noqa: E501
                .format(condition_type, allowed_values)
            )

        self._condition_type = condition_type

    @property
    def inverted(self):
        """Gets the inverted of this PolicyCondition.  # noqa: E501

        This field is deprecated. Whether to invert the condition (ie the not operator). If the condition is `a == b` inverting the condition results in `not (a == b)`  # noqa: E501

        :return: The inverted of this PolicyCondition.  # noqa: E501
        :rtype: bool
        """
        return self._inverted

    @inverted.setter
    def inverted(self, inverted):
        """Sets the inverted of this PolicyCondition.

        This field is deprecated. Whether to invert the condition (ie the not operator). If the condition is `a == b` inverting the condition results in `not (a == b)`  # noqa: E501

        :param inverted: The inverted of this PolicyCondition.  # noqa: E501
        :type: bool
        """

        self._inverted = inverted

    @property
    def input_is_list(self):
        """Gets the input_is_list of this PolicyCondition.  # noqa: E501

        Whether the input to the condition is in a list. The semantics of the condition when this flag is set is to compare every item in the list to the `value` using the `operator`. The condition is satisfied if any item in the list evaluates to true   # noqa: E501

        :return: The input_is_list of this PolicyCondition.  # noqa: E501
        :rtype: bool
        """
        return self._input_is_list

    @input_is_list.setter
    def input_is_list(self, input_is_list):
        """Sets the input_is_list of this PolicyCondition.

        Whether the input to the condition is in a list. The semantics of the condition when this flag is set is to compare every item in the list to the `value` using the `operator`. The condition is satisfied if any item in the list evaluates to true   # noqa: E501

        :param input_is_list: The input_is_list of this PolicyCondition.  # noqa: E501
        :type: bool
        """

        self._input_is_list = input_is_list

    @property
    def value(self):
        """Gets the value of this PolicyCondition.  # noqa: E501

        A JSON string representing the value to compare against. The structure of the comparision and type of the value depends on the condition type. A comparision is done to determine the result of the condition (either `true` or `false`)  # noqa: E501

        :return: The value of this PolicyCondition.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PolicyCondition.

        A JSON string representing the value to compare against. The structure of the comparision and type of the value depends on the condition type. A comparision is done to determine the result of the condition (either `true` or `false`)  # noqa: E501

        :param value: The value of this PolicyCondition.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def operator(self):
        """Gets the operator of this PolicyCondition.  # noqa: E501

        The operator used to evaluate this condition. The operator field only applies when the condition type is type_object_attribute. The other types have implied operators.  # noqa: E501

        :return: The operator of this PolicyCondition.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PolicyCondition.

        The operator used to evaluate this condition. The operator field only applies when the condition type is type_object_attribute. The other types have implied operators.  # noqa: E501

        :param operator: The operator of this PolicyCondition.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501
        allowed_values = ["equals", "not_equals", "greater_than", "less_than", "in", "not_in"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `operator` ({0}), must be one of {1}"  # noqa: E501
                .format(operator, allowed_values)
            )

        self._operator = operator

    @property
    def field(self):
        """Gets the field of this PolicyCondition.  # noqa: E501

        The object path to a field to use as input to the policy condition. This field only applies when the condition type is type_object_attribute. The supported objects are currently `users`, and `clients`.   # noqa: E501

        :return: The field of this PolicyCondition.  # noqa: E501
        :rtype: str
        """
        return self._field

    @field.setter
    def field(self, field):
        """Sets the field of this PolicyCondition.

        The object path to a field to use as input to the policy condition. This field only applies when the condition type is type_object_attribute. The supported objects are currently `users`, and `clients`.   # noqa: E501

        :param field: The field of this PolicyCondition.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                field is not None and len(field) > 511):
            raise ValueError("Invalid value for `field`, length must be less than or equal to `511`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                field is not None and not re.search(r'^([^\.]+\.?)*[^\.]+$', field)):  # noqa: E501
            raise ValueError(r"Invalid value for `field`, must be a follow pattern or equal to `/^([^\.]+\.?)*[^\.]+$/`")  # noqa: E501

        self._field = field

    @property
    def created(self):
        """Gets the created of this PolicyCondition.  # noqa: E501

        Creation time  # noqa: E501

        :return: The created of this PolicyCondition.  # noqa: E501
        :rtype: datetime
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this PolicyCondition.

        Creation time  # noqa: E501

        :param created: The created of this PolicyCondition.  # noqa: E501
        :type: datetime
        """

        self._created = created

    @property
    def updated(self):
        """Gets the updated of this PolicyCondition.  # noqa: E501

        Update time  # noqa: E501

        :return: The updated of this PolicyCondition.  # noqa: E501
        :rtype: datetime
        """
        return self._updated

    @updated.setter
    def updated(self, updated):
        """Sets the updated of this PolicyCondition.

        Update time  # noqa: E501

        :param updated: The updated of this PolicyCondition.  # noqa: E501
        :type: datetime
        """

        self._updated = updated

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicyCondition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PolicyCondition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.connector import Connector  # noqa: E501
from agilicus_api.rest import ApiException

class TestConnector(unittest.TestCase):
    """Connector unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Connector
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.connector.Connector()  # noqa: E501
        if include_optional :
            return Connector(
                metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                spec = agilicus_api.models.connector_spec.ConnectorSpec(
                    name = '0', 
                    name_slug = 'a', 
                    org_id = '123', 
                    connector_type = 'agent', 
                    service_account_id = '0', ), 
                status = agilicus_api.models.connector_status.ConnectorStatus(
                    application_services = [
                        agilicus_api.models.application_service.ApplicationService(
                            created = '2015-07-07T15:49:51.230+02:00', 
                            id = '123', 
                            name = '0', 
                            org_id = '0', 
                            hostname = 'db.example.com', 
                            ipv4_addresses = [
                                '192.0.2.1'
                                ], 
                            name_resolution = 'static', 
                            port = 56, 
                            protocol = 'tcp', 
                            assignments = [
                                agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                    app_id = '0', 
                                    environment_name = '0', 
                                    org_id = '0', )
                                ], 
                            updated = '2015-07-07T15:49:51.230+02:00', 
                            service_type = 'vpn', 
                            service_protocol_type = 'ip', 
                            connector_id = '123', )
                        ], 
                    service_account_id = '0', )
            )
        else :
            return Connector(
                spec = agilicus_api.models.connector_spec.ConnectorSpec(
                    name = '0', 
                    name_slug = 'a', 
                    org_id = '123', 
                    connector_type = 'agent', 
                    service_account_id = '0', ),
        )

    def testConnector(self):
        """Test Connector"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class AgentConnectorShareStats(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'exposed_shares_count': 'int',
        'server_running': 'bool',
        'server_start_time': 'datetime',
        'server_stop_time': 'datetime',
        'server_start_count': 'int',
        'server_stop_count': 'int',
        'per_share_info': 'list[AgentConnectorPerShareStats]'
    }

    attribute_map = {
        'exposed_shares_count': 'exposed_shares_count',
        'server_running': 'server_running',
        'server_start_time': 'server_start_time',
        'server_stop_time': 'server_stop_time',
        'server_start_count': 'server_start_count',
        'server_stop_count': 'server_stop_count',
        'per_share_info': 'per_share_info'
    }

    def __init__(self, exposed_shares_count=None, server_running=None, server_start_time=None, server_stop_time=None, server_start_count=None, server_stop_count=None, per_share_info=None, local_vars_configuration=None):  # noqa: E501
        """AgentConnectorShareStats - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._exposed_shares_count = None
        self._server_running = None
        self._server_start_time = None
        self._server_stop_time = None
        self._server_start_count = None
        self._server_stop_count = None
        self._per_share_info = None
        self.discriminator = None

        self.exposed_shares_count = exposed_shares_count
        self.server_running = server_running
        if server_start_time is not None:
            self.server_start_time = server_start_time
        if server_stop_time is not None:
            self.server_stop_time = server_stop_time
        self.server_start_count = server_start_count
        self.server_stop_count = server_stop_count
        self.per_share_info = per_share_info

    @property
    def exposed_shares_count(self):
        """Gets the exposed_shares_count of this AgentConnectorShareStats.  # noqa: E501

        The total number of shares currently exposed.  # noqa: E501

        :return: The exposed_shares_count of this AgentConnectorShareStats.  # noqa: E501
        :rtype: int
        """
        return self._exposed_shares_count

    @exposed_shares_count.setter
    def exposed_shares_count(self, exposed_shares_count):
        """Sets the exposed_shares_count of this AgentConnectorShareStats.

        The total number of shares currently exposed.  # noqa: E501

        :param exposed_shares_count: The exposed_shares_count of this AgentConnectorShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and exposed_shares_count is None:  # noqa: E501
            raise ValueError("Invalid value for `exposed_shares_count`, must not be `None`")  # noqa: E501

        self._exposed_shares_count = exposed_shares_count

    @property
    def server_running(self):
        """Gets the server_running of this AgentConnectorShareStats.  # noqa: E501

        Whether the server exposing shares is running.  # noqa: E501

        :return: The server_running of this AgentConnectorShareStats.  # noqa: E501
        :rtype: bool
        """
        return self._server_running

    @server_running.setter
    def server_running(self, server_running):
        """Sets the server_running of this AgentConnectorShareStats.

        Whether the server exposing shares is running.  # noqa: E501

        :param server_running: The server_running of this AgentConnectorShareStats.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and server_running is None:  # noqa: E501
            raise ValueError("Invalid value for `server_running`, must not be `None`")  # noqa: E501

        self._server_running = server_running

    @property
    def server_start_time(self):
        """Gets the server_start_time of this AgentConnectorShareStats.  # noqa: E501

        When the server was started. If the server has never started, this value will be ommitted.   # noqa: E501

        :return: The server_start_time of this AgentConnectorShareStats.  # noqa: E501
        :rtype: datetime
        """
        return self._server_start_time

    @server_start_time.setter
    def server_start_time(self, server_start_time):
        """Sets the server_start_time of this AgentConnectorShareStats.

        When the server was started. If the server has never started, this value will be ommitted.   # noqa: E501

        :param server_start_time: The server_start_time of this AgentConnectorShareStats.  # noqa: E501
        :type: datetime
        """

        self._server_start_time = server_start_time

    @property
    def server_stop_time(self):
        """Gets the server_stop_time of this AgentConnectorShareStats.  # noqa: E501

        When the server was stopped. If the server has never stopped, this value will be ommitted.   # noqa: E501

        :return: The server_stop_time of this AgentConnectorShareStats.  # noqa: E501
        :rtype: datetime
        """
        return self._server_stop_time

    @server_stop_time.setter
    def server_stop_time(self, server_stop_time):
        """Sets the server_stop_time of this AgentConnectorShareStats.

        When the server was stopped. If the server has never stopped, this value will be ommitted.   # noqa: E501

        :param server_stop_time: The server_stop_time of this AgentConnectorShareStats.  # noqa: E501
        :type: datetime
        """

        self._server_stop_time = server_stop_time

    @property
    def server_start_count(self):
        """Gets the server_start_count of this AgentConnectorShareStats.  # noqa: E501

        The total number of times the share server has started  # noqa: E501

        :return: The server_start_count of this AgentConnectorShareStats.  # noqa: E501
        :rtype: int
        """
        return self._server_start_count

    @server_start_count.setter
    def server_start_count(self, server_start_count):
        """Sets the server_start_count of this AgentConnectorShareStats.

        The total number of times the share server has started  # noqa: E501

        :param server_start_count: The server_start_count of this AgentConnectorShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and server_start_count is None:  # noqa: E501
            raise ValueError("Invalid value for `server_start_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                server_start_count is not None and server_start_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `server_start_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._server_start_count = server_start_count

    @property
    def server_stop_count(self):
        """Gets the server_stop_count of this AgentConnectorShareStats.  # noqa: E501

        The total number of times the share server has stopped  # noqa: E501

        :return: The server_stop_count of this AgentConnectorShareStats.  # noqa: E501
        :rtype: int
        """
        return self._server_stop_count

    @server_stop_count.setter
    def server_stop_count(self, server_stop_count):
        """Sets the server_stop_count of this AgentConnectorShareStats.

        The total number of times the share server has stopped  # noqa: E501

        :param server_stop_count: The server_stop_count of this AgentConnectorShareStats.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and server_stop_count is None:  # noqa: E501
            raise ValueError("Invalid value for `server_stop_count`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                server_stop_count is not None and server_stop_count < 0):  # noqa: E501
            raise ValueError("Invalid value for `server_stop_count`, must be a value greater than or equal to `0`")  # noqa: E501

        self._server_stop_count = server_stop_count

    @property
    def per_share_info(self):
        """Gets the per_share_info of this AgentConnectorShareStats.  # noqa: E501

        Information collected from the shares. Each share currently exposed will have a single record in this list. Shares which were once exposed, but no longer are, do not have records. If a share is later exposed, its statistics will be reset.   # noqa: E501

        :return: The per_share_info of this AgentConnectorShareStats.  # noqa: E501
        :rtype: list[AgentConnectorPerShareStats]
        """
        return self._per_share_info

    @per_share_info.setter
    def per_share_info(self, per_share_info):
        """Sets the per_share_info of this AgentConnectorShareStats.

        Information collected from the shares. Each share currently exposed will have a single record in this list. Shares which were once exposed, but no longer are, do not have records. If a share is later exposed, its statistics will be reset.   # noqa: E501

        :param per_share_info: The per_share_info of this AgentConnectorShareStats.  # noqa: E501
        :type: list[AgentConnectorPerShareStats]
        """
        if self.local_vars_configuration.client_side_validation and per_share_info is None:  # noqa: E501
            raise ValueError("Invalid value for `per_share_info`, must not be `None`")  # noqa: E501

        self._per_share_info = per_share_info

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AgentConnectorShareStats):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AgentConnectorShareStats):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class PolicySpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'issuer_id': 'str',
        'org_id': 'str',
        'supported_mfa_methods': 'list[str]',
        'default_action': 'str',
        'rules': 'list[PolicyRule]',
        'policy_groups': 'list[PolicyGroup]'
    }

    attribute_map = {
        'name': 'name',
        'issuer_id': 'issuer_id',
        'org_id': 'org_id',
        'supported_mfa_methods': 'supported_mfa_methods',
        'default_action': 'default_action',
        'rules': 'rules',
        'policy_groups': 'policy_groups'
    }

    def __init__(self, name=None, issuer_id=None, org_id=None, supported_mfa_methods=None, default_action=None, rules=None, policy_groups=None, local_vars_configuration=None):  # noqa: E501
        """PolicySpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._issuer_id = None
        self._org_id = None
        self._supported_mfa_methods = None
        self._default_action = None
        self._rules = None
        self._policy_groups = None
        self.discriminator = None

        if name is not None:
            self.name = name
        self.issuer_id = issuer_id
        if org_id is not None:
            self.org_id = org_id
        self.supported_mfa_methods = supported_mfa_methods
        self.default_action = default_action
        if rules is not None:
            self.rules = rules
        if policy_groups is not None:
            self.policy_groups = policy_groups

    @property
    def name(self):
        """Gets the name of this PolicySpec.  # noqa: E501

        The name of the policy so that it can be identifiable when applied to organizations or clients  # noqa: E501

        :return: The name of this PolicySpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PolicySpec.

        The name of the policy so that it can be identifiable when applied to organizations or clients  # noqa: E501

        :param name: The name of this PolicySpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 100):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")  # noqa: E501

        self._name = name

    @property
    def issuer_id(self):
        """Gets the issuer_id of this PolicySpec.  # noqa: E501

        The issuer that this policy applies to  # noqa: E501

        :return: The issuer_id of this PolicySpec.  # noqa: E501
        :rtype: str
        """
        return self._issuer_id

    @issuer_id.setter
    def issuer_id(self, issuer_id):
        """Sets the issuer_id of this PolicySpec.

        The issuer that this policy applies to  # noqa: E501

        :param issuer_id: The issuer_id of this PolicySpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and issuer_id is None:  # noqa: E501
            raise ValueError("Invalid value for `issuer_id`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                issuer_id is not None and len(issuer_id) > 40):
            raise ValueError("Invalid value for `issuer_id`, length must be less than or equal to `40`")  # noqa: E501

        self._issuer_id = issuer_id

    @property
    def org_id(self):
        """Gets the org_id of this PolicySpec.  # noqa: E501

        The org id corresponding to the issuer whose policy you are updating  # noqa: E501

        :return: The org_id of this PolicySpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this PolicySpec.

        The org id corresponding to the issuer whose policy you are updating  # noqa: E501

        :param org_id: The org_id of this PolicySpec.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                org_id is not None and len(org_id) > 40):
            raise ValueError("Invalid value for `org_id`, length must be less than or equal to `40`")  # noqa: E501

        self._org_id = org_id

    @property
    def supported_mfa_methods(self):
        """Gets the supported_mfa_methods of this PolicySpec.  # noqa: E501

        A list of supported MFA methods. An empty list implies that no MFA methods are acceptable  # noqa: E501

        :return: The supported_mfa_methods of this PolicySpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_mfa_methods

    @supported_mfa_methods.setter
    def supported_mfa_methods(self, supported_mfa_methods):
        """Sets the supported_mfa_methods of this PolicySpec.

        A list of supported MFA methods. An empty list implies that no MFA methods are acceptable  # noqa: E501

        :param supported_mfa_methods: The supported_mfa_methods of this PolicySpec.  # noqa: E501
        :type: list[str]
        """
        if self.local_vars_configuration.client_side_validation and supported_mfa_methods is None:  # noqa: E501
            raise ValueError("Invalid value for `supported_mfa_methods`, must not be `None`")  # noqa: E501

        self._supported_mfa_methods = supported_mfa_methods

    @property
    def default_action(self):
        """Gets the default_action of this PolicySpec.  # noqa: E501

        The action to take if none of the conditions evaluate to true. Actions are case sensitive.  # noqa: E501

        :return: The default_action of this PolicySpec.  # noqa: E501
        :rtype: str
        """
        return self._default_action

    @default_action.setter
    def default_action(self, default_action):
        """Sets the default_action of this PolicySpec.

        The action to take if none of the conditions evaluate to true. Actions are case sensitive.  # noqa: E501

        :param default_action: The default_action of this PolicySpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and default_action is None:  # noqa: E501
            raise ValueError("Invalid value for `default_action`, must not be `None`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                default_action is not None and len(default_action) > 100):
            raise ValueError("Invalid value for `default_action`, length must be less than or equal to `100`")  # noqa: E501

        self._default_action = default_action

    @property
    def rules(self):
        """Gets the rules of this PolicySpec.  # noqa: E501

        The list of rules defining the policy. A rule consists of conditions, actions, and a priority  # noqa: E501

        :return: The rules of this PolicySpec.  # noqa: E501
        :rtype: list[PolicyRule]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """Sets the rules of this PolicySpec.

        The list of rules defining the policy. A rule consists of conditions, actions, and a priority  # noqa: E501

        :param rules: The rules of this PolicySpec.  # noqa: E501
        :type: list[PolicyRule]
        """

        self._rules = rules

    @property
    def policy_groups(self):
        """Gets the policy_groups of this PolicySpec.  # noqa: E501

        A list of policy groups ordered by priority. The first item in the list represents the group with the highest priority. A policy group consists of a list of rules. All rules in a group of higher priority will have higher precedence than any rule in a group of lower priority.   # noqa: E501

        :return: The policy_groups of this PolicySpec.  # noqa: E501
        :rtype: list[PolicyGroup]
        """
        return self._policy_groups

    @policy_groups.setter
    def policy_groups(self, policy_groups):
        """Sets the policy_groups of this PolicySpec.

        A list of policy groups ordered by priority. The first item in the list represents the group with the highest priority. A policy group consists of a list of rules. All rules in a group of higher priority will have higher precedence than any rule in a group of lower priority.   # noqa: E501

        :param policy_groups: The policy_groups of this PolicySpec.  # noqa: E501
        :type: list[PolicyGroup]
        """

        self._policy_groups = policy_groups

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PolicySpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PolicySpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.ipsec_connector_spec import IpsecConnectorSpec  # noqa: E501
from agilicus_api.rest import ApiException

class TestIpsecConnectorSpec(unittest.TestCase):
    """IpsecConnectorSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test IpsecConnectorSpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.ipsec_connector_spec.IpsecConnectorSpec()  # noqa: E501
        if include_optional :
            return IpsecConnectorSpec(
                name = 'ipsec1', 
                name_slug = 'a', 
                org_id = '123', 
                ipsec_gateway_id = '1234', 
                connections = [
                    agilicus_api.models.ipsec_connection.IpsecConnection(
                        name = '0', 
                        inherit_from = '0', 
                        gateway_interface = agilicus_api.models.ipsec_gateway_interface.IpsecGatewayInterface(
                            name = 'a', 
                            hostname = 'vpn-1', 
                            certificate_dn = 'C=US, O=LetsEncrypt, CN=R3', ), 
                        spec = agilicus_api.models.ipsec_connection_spec.IpsecConnectionSpec(
                            ike_version = 'ikev1', 
                            remote_ipv4_address = '0', 
                            remote_dns_ipv4_address = '0', 
                            remote_healthcheck_ipv4_address = '0', 
                            ike_cipher_encryption_algorithm = 'aes128', 
                            ike_cipher_integrity_algorithm = 'sha256', 
                            ike_cipher_diffie_hellman_group = 'ecp256', 
                            esp_cipher_encryption_algorithm = 'aes128', 
                            esp_cipher_integrity_algorithm = 'sha256', 
                            esp_cipher_diffie_hellman_group = 'ecp256', 
                            esp_lifetime = 56, 
                            ike_lifetime = 56, 
                            ike_rekey = True, 
                            ike_reauth = True, 
                            ike_authentication_type = 'ike_preshared_key', 
                            ike_preshared_key = '0', 
                            ike_chain_of_trust_certificates = '0', 
                            ike_certificate_dn = '0', 
                            local_ipv4_block = '192.168.3.0/30', 
                            remote_ipv4_ranges = [
                                agilicus_api.models.ipsec_connection_ipv4_block.IpsecConnectionIpv4Block(
                                    ipv4_address_block = '192.168.2.1/30', )
                                ], ), )
                    ]
            )
        else :
            return IpsecConnectorSpec(
                name = 'ipsec1',
                org_id = '123',
        )

    def testIpsecConnectorSpec(self):
        """Test IpsecConnectorSpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class APIKeySpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'user_id': 'str',
        'org_id': 'str',
        'expiry': 'datetime',
        'session': 'str',
        'scopes': 'list[str]'
    }

    attribute_map = {
        'user_id': 'user_id',
        'org_id': 'org_id',
        'expiry': 'expiry',
        'session': 'session',
        'scopes': 'scopes'
    }

    def __init__(self, user_id=None, org_id=None, expiry=None, session=None, scopes=None, local_vars_configuration=None):  # noqa: E501
        """APIKeySpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._user_id = None
        self._org_id = None
        self._expiry = None
        self._session = None
        self._scopes = None
        self.discriminator = None

        self.user_id = user_id
        self.org_id = org_id
        if expiry is not None:
            self.expiry = expiry
        if session is not None:
            self.session = session
        if scopes is not None:
            self.scopes = scopes

    @property
    def user_id(self):
        """Gets the user_id of this APIKeySpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The user_id of this APIKeySpec.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this APIKeySpec.

        Unique identifier  # noqa: E501

        :param user_id: The user_id of this APIKeySpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and user_id is None:  # noqa: E501
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def org_id(self):
        """Gets the org_id of this APIKeySpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The org_id of this APIKeySpec.  # noqa: E501
        :rtype: str
        """
        return self._org_id

    @org_id.setter
    def org_id(self, org_id):
        """Sets the org_id of this APIKeySpec.

        Unique identifier  # noqa: E501

        :param org_id: The org_id of this APIKeySpec.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and org_id is None:  # noqa: E501
            raise ValueError("Invalid value for `org_id`, must not be `None`")  # noqa: E501

        self._org_id = org_id

    @property
    def expiry(self):
        """Gets the expiry of this APIKeySpec.  # noqa: E501

        The API Key expiry time in UTC. If ommitted the key does not expire.  # noqa: E501

        :return: The expiry of this APIKeySpec.  # noqa: E501
        :rtype: datetime
        """
        return self._expiry

    @expiry.setter
    def expiry(self, expiry):
        """Sets the expiry of this APIKeySpec.

        The API Key expiry time in UTC. If ommitted the key does not expire.  # noqa: E501

        :param expiry: The expiry of this APIKeySpec.  # noqa: E501
        :type: datetime
        """

        self._expiry = expiry

    @property
    def session(self):
        """Gets the session of this APIKeySpec.  # noqa: E501

        Unique identifier  # noqa: E501

        :return: The session of this APIKeySpec.  # noqa: E501
        :rtype: str
        """
        return self._session

    @session.setter
    def session(self, session):
        """Sets the session of this APIKeySpec.

        Unique identifier  # noqa: E501

        :param session: The session of this APIKeySpec.  # noqa: E501
        :type: str
        """

        self._session = session

    @property
    def scopes(self):
        """Gets the scopes of this APIKeySpec.  # noqa: E501

        The list of scopes requested for APIKey. Ex. urn:agilicus:users. An optional scope is specified with an ? at the end. Optional scopes are used when the permission is requested but not required. Ex. urn:agilicus:users?. A non-optional scope will cause creation of this API Key to fail if the user does not have that permission in this org.   # noqa: E501

        :return: The scopes of this APIKeySpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._scopes

    @scopes.setter
    def scopes(self, scopes):
        """Sets the scopes of this APIKeySpec.

        The list of scopes requested for APIKey. Ex. urn:agilicus:users. An optional scope is specified with an ? at the end. Optional scopes are used when the permission is requested but not required. Ex. urn:agilicus:users?. A non-optional scope will cause creation of this API Key to fail if the user does not have that permission in this org.   # noqa: E501

        :param scopes: The scopes of this APIKeySpec.  # noqa: E501
        :type: list[str]
        """

        self._scopes = scopes

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, APIKeySpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, APIKeySpec):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from agilicus_api.configuration import Configuration


class FileShareServiceStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'share_base_app_name': 'str',
        'instance_id': 'str',
        'instance_org_id': 'str'
    }

    attribute_map = {
        'share_base_app_name': 'share_base_app_name',
        'instance_id': 'instance_id',
        'instance_org_id': 'instance_org_id'
    }

    def __init__(self, share_base_app_name=None, instance_id=None, instance_org_id=None, local_vars_configuration=None):  # noqa: E501
        """FileShareServiceStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._share_base_app_name = None
        self._instance_id = None
        self._instance_org_id = None
        self.discriminator = None

        if share_base_app_name is not None:
            self.share_base_app_name = share_base_app_name
        if instance_id is not None:
            self.instance_id = instance_id
        if instance_org_id is not None:
            self.instance_org_id = instance_org_id

    @property
    def share_base_app_name(self):
        """Gets the share_base_app_name of this FileShareServiceStatus.  # noqa: E501

        The name of the application in the system providing the file share. This can be used to construct the default URI used to access the file share given the organisation's subdomain.   # noqa: E501

        :return: The share_base_app_name of this FileShareServiceStatus.  # noqa: E501
        :rtype: str
        """
        return self._share_base_app_name

    @share_base_app_name.setter
    def share_base_app_name(self, share_base_app_name):
        """Sets the share_base_app_name of this FileShareServiceStatus.

        The name of the application in the system providing the file share. This can be used to construct the default URI used to access the file share given the organisation's subdomain.   # noqa: E501

        :param share_base_app_name: The share_base_app_name of this FileShareServiceStatus.  # noqa: E501
        :type: str
        """

        self._share_base_app_name = share_base_app_name

    @property
    def instance_id(self):
        """Gets the instance_id of this FileShareServiceStatus.  # noqa: E501

        The identifier of the instance running the file share. Useful for auditing/etc.   # noqa: E501

        :return: The instance_id of this FileShareServiceStatus.  # noqa: E501
        :rtype: str
        """
        return self._instance_id

    @instance_id.setter
    def instance_id(self, instance_id):
        """Sets the instance_id of this FileShareServiceStatus.

        The identifier of the instance running the file share. Useful for auditing/etc.   # noqa: E501

        :param instance_id: The instance_id of this FileShareServiceStatus.  # noqa: E501
        :type: str
        """

        self._instance_id = instance_id

    @property
    def instance_org_id(self):
        """Gets the instance_org_id of this FileShareServiceStatus.  # noqa: E501

        The identifier of the organistion responsible for the instance running the file share.   # noqa: E501

        :return: The instance_org_id of this FileShareServiceStatus.  # noqa: E501
        :rtype: str
        """
        return self._instance_org_id

    @instance_org_id.setter
    def instance_org_id(self, instance_org_id):
        """Sets the instance_org_id of this FileShareServiceStatus.

        The identifier of the organistion responsible for the instance running the file share.   # noqa: E501

        :param instance_org_id: The instance_org_id of this FileShareServiceStatus.  # noqa: E501
        :type: str
        """

        self._instance_org_id = instance_org_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FileShareServiceStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FileShareServiceStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from agilicus_api.api_client import ApiClient
from agilicus_api.exceptions import (
    ApiTypeError,
    ApiValueError
)


class ChallengesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_challenge(self, challenge, **kwargs):  # noqa: E501
        """create a challenge  # noqa: E501

        Creates a challenge according to the provide specification. This challenge will persist for a period of time waiting for the challenge to be passed. It will eventually time out.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_challenge(challenge, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Challenge challenge: The challenge to create (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Challenge
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_challenge_with_http_info(challenge, **kwargs)  # noqa: E501

    def create_challenge_with_http_info(self, challenge, **kwargs):  # noqa: E501
        """create a challenge  # noqa: E501

        Creates a challenge according to the provide specification. This challenge will persist for a period of time waiting for the challenge to be passed. It will eventually time out.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_challenge_with_http_info(challenge, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Challenge challenge: The challenge to create (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Challenge, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['challenge']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_challenge" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'challenge' is set
        if self.api_client.client_side_validation and ('challenge' not in local_var_params or  # noqa: E501
                                                        local_var_params['challenge'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `challenge` when calling `create_challenge`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'challenge' in local_var_params:
            body_params = local_var_params['challenge']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenges', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Challenge',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_totp_enrollment(self, totp_enrollment, **kwargs):  # noqa: E501
        """create a TOTP challenge enrollment  # noqa: E501

        Creates a TOTP challenge enrollment. The returned body will contain the key the user needs to enroll in their application. The enrollment is not complete until the user provides a valid answer.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_totp_enrollment(totp_enrollment, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param TOTPEnrollment totp_enrollment: The TOTP challenge enrollment to create. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TOTPEnrollment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_totp_enrollment_with_http_info(totp_enrollment, **kwargs)  # noqa: E501

    def create_totp_enrollment_with_http_info(self, totp_enrollment, **kwargs):  # noqa: E501
        """create a TOTP challenge enrollment  # noqa: E501

        Creates a TOTP challenge enrollment. The returned body will contain the key the user needs to enroll in their application. The enrollment is not complete until the user provides a valid answer.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_totp_enrollment_with_http_info(totp_enrollment, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param TOTPEnrollment totp_enrollment: The TOTP challenge enrollment to create. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TOTPEnrollment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['totp_enrollment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_totp_enrollment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'totp_enrollment' is set
        if self.api_client.client_side_validation and ('totp_enrollment' not in local_var_params or  # noqa: E501
                                                        local_var_params['totp_enrollment'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `totp_enrollment` when calling `create_totp_enrollment`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'totp_enrollment' in local_var_params:
            body_params = local_var_params['totp_enrollment']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/totp', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TOTPEnrollment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_webauthn_enrollment(self, web_auth_n_enrollment, **kwargs):  # noqa: E501
        """create a WebAuthN challenge enrollment  # noqa: E501

        Initiates a WebAuthN challenge enrollment. The enrollment is not complete until the user provides a valid answer.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_webauthn_enrollment(web_auth_n_enrollment, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param WebAuthNEnrollment web_auth_n_enrollment: The WebAuthN challenge enrollment to create. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WebAuthNEnrollment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_webauthn_enrollment_with_http_info(web_auth_n_enrollment, **kwargs)  # noqa: E501

    def create_webauthn_enrollment_with_http_info(self, web_auth_n_enrollment, **kwargs):  # noqa: E501
        """create a WebAuthN challenge enrollment  # noqa: E501

        Initiates a WebAuthN challenge enrollment. The enrollment is not complete until the user provides a valid answer.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_webauthn_enrollment_with_http_info(web_auth_n_enrollment, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param WebAuthNEnrollment web_auth_n_enrollment: The WebAuthN challenge enrollment to create. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WebAuthNEnrollment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['web_auth_n_enrollment']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_webauthn_enrollment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'web_auth_n_enrollment' is set
        if self.api_client.client_side_validation and ('web_auth_n_enrollment' not in local_var_params or  # noqa: E501
                                                        local_var_params['web_auth_n_enrollment'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `web_auth_n_enrollment` when calling `create_webauthn_enrollment`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'web_auth_n_enrollment' in local_var_params:
            body_params = local_var_params['web_auth_n_enrollment']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/webauthn', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebAuthNEnrollment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_challenge(self, challenge_id, **kwargs):  # noqa: E501
        """Delete the challenge specified by challenge_id  # noqa: E501

        Delete the challenge specified by challenge_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_challenge(challenge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str challenge_id: A challenge id found in a path. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_challenge_with_http_info(challenge_id, **kwargs)  # noqa: E501

    def delete_challenge_with_http_info(self, challenge_id, **kwargs):  # noqa: E501
        """Delete the challenge specified by challenge_id  # noqa: E501

        Delete the challenge specified by challenge_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_challenge_with_http_info(challenge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str challenge_id: A challenge id found in a path. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['challenge_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_challenge" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'challenge_id' is set
        if self.api_client.client_side_validation and ('challenge_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['challenge_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `challenge_id` when calling `delete_challenge`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'challenge_id' in local_var_params:
            path_params['challenge_id'] = local_var_params['challenge_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenges/{challenge_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_totp_enrollment(self, totp_id, **kwargs):  # noqa: E501
        """Delete the TOTP enrollment specified by totp id  # noqa: E501

        Delete the TOTP enrollment specified by totp id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_totp_enrollment(totp_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str totp_id: A totp id found in a path. (required)
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_totp_enrollment_with_http_info(totp_id, **kwargs)  # noqa: E501

    def delete_totp_enrollment_with_http_info(self, totp_id, **kwargs):  # noqa: E501
        """Delete the TOTP enrollment specified by totp id  # noqa: E501

        Delete the TOTP enrollment specified by totp id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_totp_enrollment_with_http_info(totp_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str totp_id: A totp id found in a path. (required)
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['totp_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_totp_enrollment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'totp_id' is set
        if self.api_client.client_side_validation and ('totp_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['totp_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `totp_id` when calling `delete_totp_enrollment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'totp_id' in local_var_params:
            path_params['totp_id'] = local_var_params['totp_id']  # noqa: E501

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/totp/{totp_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_webauthn_enrollment(self, webauthn_id, **kwargs):  # noqa: E501
        """Delete the WebAuthN enrollment specified by webauthn_id  # noqa: E501

        Delete the WebAuthN enrollment specified by webauthn_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_webauthn_enrollment(webauthn_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str webauthn_id: A webauthn id found in a path. (required)
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_webauthn_enrollment_with_http_info(webauthn_id, **kwargs)  # noqa: E501

    def delete_webauthn_enrollment_with_http_info(self, webauthn_id, **kwargs):  # noqa: E501
        """Delete the WebAuthN enrollment specified by webauthn_id  # noqa: E501

        Delete the WebAuthN enrollment specified by webauthn_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_webauthn_enrollment_with_http_info(webauthn_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str webauthn_id: A webauthn id found in a path. (required)
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['webauthn_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_webauthn_enrollment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'webauthn_id' is set
        if self.api_client.client_side_validation and ('webauthn_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['webauthn_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `webauthn_id` when calling `delete_webauthn_enrollment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'webauthn_id' in local_var_params:
            path_params['webauthn_id'] = local_var_params['webauthn_id']  # noqa: E501

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/webauthn/{webauthn_id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_answer(self, challenge_id, challenge_answer, challenge_uid, allowed, challenge_type, **kwargs):  # noqa: E501
        """answer a challenge  # noqa: E501

        Checks whether the challenge answer is correct. If the challenge is not accepting answers, or the anwer is incorrect, a failure will be returned. Otherwise, the challenge will be considered answered and the user can log in.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_answer(challenge_id, challenge_answer, challenge_uid, allowed, challenge_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str challenge_id: A challenge id found in a path. (required)
        :param str challenge_answer: The answer for the challenge (required)
        :param str challenge_uid: The user id for the challenge (required)
        :param bool allowed: Whether the challenge was allowed. If true, then the user can proceed with the login. If false, then the user will be denied their login attempt. Set this to false if the login attempt was not desired.  (required)
        :param str challenge_type: challenge method type query (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ChallengeAnswer
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_answer_with_http_info(challenge_id, challenge_answer, challenge_uid, allowed, challenge_type, **kwargs)  # noqa: E501

    def get_answer_with_http_info(self, challenge_id, challenge_answer, challenge_uid, allowed, challenge_type, **kwargs):  # noqa: E501
        """answer a challenge  # noqa: E501

        Checks whether the challenge answer is correct. If the challenge is not accepting answers, or the anwer is incorrect, a failure will be returned. Otherwise, the challenge will be considered answered and the user can log in.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_answer_with_http_info(challenge_id, challenge_answer, challenge_uid, allowed, challenge_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str challenge_id: A challenge id found in a path. (required)
        :param str challenge_answer: The answer for the challenge (required)
        :param str challenge_uid: The user id for the challenge (required)
        :param bool allowed: Whether the challenge was allowed. If true, then the user can proceed with the login. If false, then the user will be denied their login attempt. Set this to false if the login attempt was not desired.  (required)
        :param str challenge_type: challenge method type query (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ChallengeAnswer, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['challenge_id', 'challenge_answer', 'challenge_uid', 'allowed', 'challenge_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_answer" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'challenge_id' is set
        if self.api_client.client_side_validation and ('challenge_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['challenge_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `challenge_id` when calling `get_answer`")  # noqa: E501
        # verify the required parameter 'challenge_answer' is set
        if self.api_client.client_side_validation and ('challenge_answer' not in local_var_params or  # noqa: E501
                                                        local_var_params['challenge_answer'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `challenge_answer` when calling `get_answer`")  # noqa: E501
        # verify the required parameter 'challenge_uid' is set
        if self.api_client.client_side_validation and ('challenge_uid' not in local_var_params or  # noqa: E501
                                                        local_var_params['challenge_uid'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `challenge_uid` when calling `get_answer`")  # noqa: E501
        # verify the required parameter 'allowed' is set
        if self.api_client.client_side_validation and ('allowed' not in local_var_params or  # noqa: E501
                                                        local_var_params['allowed'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `allowed` when calling `get_answer`")  # noqa: E501
        # verify the required parameter 'challenge_type' is set
        if self.api_client.client_side_validation and ('challenge_type' not in local_var_params or  # noqa: E501
                                                        local_var_params['challenge_type'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `challenge_type` when calling `get_answer`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'challenge_id' in local_var_params:
            path_params['challenge_id'] = local_var_params['challenge_id']  # noqa: E501

        query_params = []
        if 'challenge_answer' in local_var_params and local_var_params['challenge_answer'] is not None:  # noqa: E501
            query_params.append(('challenge_answer', local_var_params['challenge_answer']))  # noqa: E501
        if 'challenge_uid' in local_var_params and local_var_params['challenge_uid'] is not None:  # noqa: E501
            query_params.append(('challenge_uid', local_var_params['challenge_uid']))  # noqa: E501
        if 'allowed' in local_var_params and local_var_params['allowed'] is not None:  # noqa: E501
            query_params.append(('allowed', local_var_params['allowed']))  # noqa: E501
        if 'challenge_type' in local_var_params and local_var_params['challenge_type'] is not None:  # noqa: E501
            query_params.append(('challenge_type', local_var_params['challenge_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenges/{challenge_id}/answers', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ChallengeAnswer',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_challenge(self, challenge_id, **kwargs):  # noqa: E501
        """Get the challenge specified by challenge_id  # noqa: E501

        Get the challenge specified by challenge_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_challenge(challenge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str challenge_id: A challenge id found in a path. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Challenge
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_challenge_with_http_info(challenge_id, **kwargs)  # noqa: E501

    def get_challenge_with_http_info(self, challenge_id, **kwargs):  # noqa: E501
        """Get the challenge specified by challenge_id  # noqa: E501

        Get the challenge specified by challenge_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_challenge_with_http_info(challenge_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str challenge_id: A challenge id found in a path. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Challenge, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['challenge_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_challenge" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'challenge_id' is set
        if self.api_client.client_side_validation and ('challenge_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['challenge_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `challenge_id` when calling `get_challenge`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'challenge_id' in local_var_params:
            path_params['challenge_id'] = local_var_params['challenge_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenges/{challenge_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Challenge',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_totp_enrollment(self, totp_id, **kwargs):  # noqa: E501
        """Get the TOTP enrollment specified by totp_id  # noqa: E501

        Get the TOTP enrollment specified by totp_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_totp_enrollment(totp_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str totp_id: A totp id found in a path. (required)
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TOTPEnrollment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_totp_enrollment_with_http_info(totp_id, **kwargs)  # noqa: E501

    def get_totp_enrollment_with_http_info(self, totp_id, **kwargs):  # noqa: E501
        """Get the TOTP enrollment specified by totp_id  # noqa: E501

        Get the TOTP enrollment specified by totp_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_totp_enrollment_with_http_info(totp_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str totp_id: A totp id found in a path. (required)
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TOTPEnrollment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['totp_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_totp_enrollment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'totp_id' is set
        if self.api_client.client_side_validation and ('totp_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['totp_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `totp_id` when calling `get_totp_enrollment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'totp_id' in local_var_params:
            path_params['totp_id'] = local_var_params['totp_id']  # noqa: E501

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/totp/{totp_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TOTPEnrollment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_webauthn_enrollment(self, webauthn_id, **kwargs):  # noqa: E501
        """Get the WebAuthN enrollment specified by webauthn_id  # noqa: E501

        Get the WebAuthN enrollment specified by webauthn_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webauthn_enrollment(webauthn_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str webauthn_id: A webauthn id found in a path. (required)
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WebAuthNEnrollment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_webauthn_enrollment_with_http_info(webauthn_id, **kwargs)  # noqa: E501

    def get_webauthn_enrollment_with_http_info(self, webauthn_id, **kwargs):  # noqa: E501
        """Get the WebAuthN enrollment specified by webauthn_id  # noqa: E501

        Get the WebAuthN enrollment specified by webauthn_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_webauthn_enrollment_with_http_info(webauthn_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str webauthn_id: A webauthn id found in a path. (required)
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WebAuthNEnrollment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['webauthn_id', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_webauthn_enrollment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'webauthn_id' is set
        if self.api_client.client_side_validation and ('webauthn_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['webauthn_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `webauthn_id` when calling `get_webauthn_enrollment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'webauthn_id' in local_var_params:
            path_params['webauthn_id'] = local_var_params['webauthn_id']  # noqa: E501

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/webauthn/{webauthn_id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebAuthNEnrollment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_totp_enrollment(self, **kwargs):  # noqa: E501
        """List the totp enrollment results  # noqa: E501

        List the totp enrollment results  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_totp_enrollment(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: limit the number of rows in the response
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListTOTPEnrollmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_totp_enrollment_with_http_info(**kwargs)  # noqa: E501

    def list_totp_enrollment_with_http_info(self, **kwargs):  # noqa: E501
        """List the totp enrollment results  # noqa: E501

        List the totp enrollment results  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_totp_enrollment_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: limit the number of rows in the response
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListTOTPEnrollmentResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['limit', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_totp_enrollment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 500:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_totp_enrollment`, must be a value less than or equal to `500`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_totp_enrollment`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/totp', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListTOTPEnrollmentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_webauthn_enrollments(self, **kwargs):  # noqa: E501
        """List the webauthn enrollments  # noqa: E501

        List the webauthn enrollments  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_webauthn_enrollments(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: limit the number of rows in the response
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ListWebAuthNEnrollmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_webauthn_enrollments_with_http_info(**kwargs)  # noqa: E501

    def list_webauthn_enrollments_with_http_info(self, **kwargs):  # noqa: E501
        """List the webauthn enrollments  # noqa: E501

        List the webauthn enrollments  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_webauthn_enrollments_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int limit: limit the number of rows in the response
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ListWebAuthNEnrollmentResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['limit', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_webauthn_enrollments" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] > 500:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_webauthn_enrollments`, must be a value less than or equal to `500`")  # noqa: E501
        if self.api_client.client_side_validation and 'limit' in local_var_params and local_var_params['limit'] < 1:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `limit` when calling `list_webauthn_enrollments`, must be a value greater than or equal to `1`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'limit' in local_var_params and local_var_params['limit'] is not None:  # noqa: E501
            query_params.append(('limit', local_var_params['limit']))  # noqa: E501
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/webauthn', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListWebAuthNEnrollmentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def replace_challenge(self, challenge_id, challenge, **kwargs):  # noqa: E501
        """Replace the challenge specified by challenge_id  # noqa: E501

        Replace the challenge specified by challenge_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_challenge(challenge_id, challenge, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str challenge_id: A challenge id found in a path. (required)
        :param Challenge challenge: The challenge to replace. Note that some fields, such as user_id, cannot be modified. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Challenge
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.replace_challenge_with_http_info(challenge_id, challenge, **kwargs)  # noqa: E501

    def replace_challenge_with_http_info(self, challenge_id, challenge, **kwargs):  # noqa: E501
        """Replace the challenge specified by challenge_id  # noqa: E501

        Replace the challenge specified by challenge_id  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.replace_challenge_with_http_info(challenge_id, challenge, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str challenge_id: A challenge id found in a path. (required)
        :param Challenge challenge: The challenge to replace. Note that some fields, such as user_id, cannot be modified. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(Challenge, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['challenge_id', 'challenge']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace_challenge" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'challenge_id' is set
        if self.api_client.client_side_validation and ('challenge_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['challenge_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `challenge_id` when calling `replace_challenge`")  # noqa: E501
        # verify the required parameter 'challenge' is set
        if self.api_client.client_side_validation and ('challenge' not in local_var_params or  # noqa: E501
                                                        local_var_params['challenge'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `challenge` when calling `replace_challenge`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'challenge_id' in local_var_params:
            path_params['challenge_id'] = local_var_params['challenge_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'challenge' in local_var_params:
            body_params = local_var_params['challenge']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenges/{challenge_id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Challenge',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_totp_enrollment(self, totp_id, totp_enrollment_answer, **kwargs):  # noqa: E501
        """Update the totp_enrollment if the answer provided is correct.  # noqa: E501

        Update the totp_enrollment if the answer provided is correct. This moves the state from pending to success.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_totp_enrollment(totp_id, totp_enrollment_answer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str totp_id: A totp id found in a path. (required)
        :param TOTPEnrollmentAnswer totp_enrollment_answer: The answer to the TOTP enrollment specified by totp_id. (required)
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: TOTPEnrollment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_totp_enrollment_with_http_info(totp_id, totp_enrollment_answer, **kwargs)  # noqa: E501

    def update_totp_enrollment_with_http_info(self, totp_id, totp_enrollment_answer, **kwargs):  # noqa: E501
        """Update the totp_enrollment if the answer provided is correct.  # noqa: E501

        Update the totp_enrollment if the answer provided is correct. This moves the state from pending to success.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_totp_enrollment_with_http_info(totp_id, totp_enrollment_answer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str totp_id: A totp id found in a path. (required)
        :param TOTPEnrollmentAnswer totp_enrollment_answer: The answer to the TOTP enrollment specified by totp_id. (required)
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(TOTPEnrollment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['totp_id', 'totp_enrollment_answer', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_totp_enrollment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'totp_id' is set
        if self.api_client.client_side_validation and ('totp_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['totp_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `totp_id` when calling `update_totp_enrollment`")  # noqa: E501
        # verify the required parameter 'totp_enrollment_answer' is set
        if self.api_client.client_side_validation and ('totp_enrollment_answer' not in local_var_params or  # noqa: E501
                                                        local_var_params['totp_enrollment_answer'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `totp_enrollment_answer` when calling `update_totp_enrollment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'totp_id' in local_var_params:
            path_params['totp_id'] = local_var_params['totp_id']  # noqa: E501

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'totp_enrollment_answer' in local_var_params:
            body_params = local_var_params['totp_enrollment_answer']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/totp/{totp_id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='TOTPEnrollment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_webauthn_enrollment(self, webauthn_id, web_auth_n_enrollment_answer, **kwargs):  # noqa: E501
        """Update the WebAuthN enrollment if the answer provided is correct.  # noqa: E501

        Update the WebAuthN enrollment if the answer provided is correct. This completes the device enrollment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_webauthn_enrollment(webauthn_id, web_auth_n_enrollment_answer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str webauthn_id: A webauthn id found in a path. (required)
        :param WebAuthNEnrollmentAnswer web_auth_n_enrollment_answer: The answer to the WebAuthN enrollment specified by webauthn_id. (required)
        :param str user_id: Query based on user id
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: WebAuthNEnrollment
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_webauthn_enrollment_with_http_info(webauthn_id, web_auth_n_enrollment_answer, **kwargs)  # noqa: E501

    def update_webauthn_enrollment_with_http_info(self, webauthn_id, web_auth_n_enrollment_answer, **kwargs):  # noqa: E501
        """Update the WebAuthN enrollment if the answer provided is correct.  # noqa: E501

        Update the WebAuthN enrollment if the answer provided is correct. This completes the device enrollment.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_webauthn_enrollment_with_http_info(webauthn_id, web_auth_n_enrollment_answer, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str webauthn_id: A webauthn id found in a path. (required)
        :param WebAuthNEnrollmentAnswer web_auth_n_enrollment_answer: The answer to the WebAuthN enrollment specified by webauthn_id. (required)
        :param str user_id: Query based on user id
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(WebAuthNEnrollment, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = ['webauthn_id', 'web_auth_n_enrollment_answer', 'user_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_webauthn_enrollment" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'webauthn_id' is set
        if self.api_client.client_side_validation and ('webauthn_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['webauthn_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `webauthn_id` when calling `update_webauthn_enrollment`")  # noqa: E501
        # verify the required parameter 'web_auth_n_enrollment_answer' is set
        if self.api_client.client_side_validation and ('web_auth_n_enrollment_answer' not in local_var_params or  # noqa: E501
                                                        local_var_params['web_auth_n_enrollment_answer'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `web_auth_n_enrollment_answer` when calling `update_webauthn_enrollment`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'webauthn_id' in local_var_params:
            path_params['webauthn_id'] = local_var_params['webauthn_id']  # noqa: E501

        query_params = []
        if 'user_id' in local_var_params and local_var_params['user_id'] is not None:  # noqa: E501
            query_params.append(('user_id', local_var_params['user_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'web_auth_n_enrollment_answer' in local_var_params:
            body_params = local_var_params['web_auth_n_enrollment_answer']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['token-valid']  # noqa: E501

        return self.api_client.call_api(
            '/v1/challenge_enrollment/webauthn/{webauthn_id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='WebAuthNEnrollment',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import agilicus_api
from agilicus_api.api.services_api import ServicesApi  # noqa: E501
from agilicus_api.rest import ApiException


class TestServicesApi(unittest.TestCase):
    """ServicesApi unit test stubs"""

    def setUp(self):
        self.api = agilicus_api.api.services_api.ServicesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_service(self):
        """Test case for create_service

        Create a Service  # noqa: E501
        """
        pass

    def test_delete_service(self):
        """Test case for delete_service

        Remove a Service  # noqa: E501
        """
        pass

    def test_get_service(self):
        """Test case for get_service

        Get a single Service  # noqa: E501
        """
        pass

    def test_list_services(self):
        """Test case for list_services

        Get a subset of the Services  # noqa: E501
        """
        pass

    def test_replace_service(self):
        """Test case for replace_service

        Create or update a Service.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Agilicus API

    Agilicus API endpoints  # noqa: E501

    The version of the OpenAPI document: 2021.02.12
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.agent_connector_status import AgentConnectorStatus  # noqa: E501
from agilicus_api.rest import ApiException

class TestAgentConnectorStatus(unittest.TestCase):
    """AgentConnectorStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AgentConnectorStatus
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.agent_connector_status.AgentConnectorStatus()  # noqa: E501
        if include_optional :
            return AgentConnectorStatus(
                application_services = [
                    agilicus_api.models.application_service.ApplicationService(
                        created = '2015-07-07T15:49:51.230+02:00', 
                        id = '123', 
                        name = '0', 
                        org_id = '0', 
                        hostname = 'db.example.com', 
                        ipv4_addresses = [
                            '192.0.2.1'
                            ], 
                        name_resolution = 'static', 
                        port = 56, 
                        protocol = 'tcp', 
                        assignments = [
                            agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                app_id = '0', 
                                environment_name = '0', 
                                org_id = '0', )
                            ], 
                        updated = '2015-07-07T15:49:51.230+02:00', 
                        service_type = 'vpn', 
                        service_protocol_type = 'ip', 
                        connector_id = '123', )
                    ], 
                service_account_id = '0', 
                info = agilicus_api.models.agent_connector_info.AgentConnectorInfo(
                    connections_info = [
                        agilicus_api.models.agent_connector_connection_info.AgentConnectorConnectionInfo(
                            connection_uri = 'wss://my-app.example.com/.agilcus-agent', 
                            connection_location = 'my-app.example.com', 
                            connection_path = '/.agilicus-agent', 
                            connection_org_id = 'asda93oidl2xZ6', 
                            connection_app_name = 'my-app', 
                            max_number_connections = 0, 
                            ip_services = [
                                agilicus_api.models.application_service.ApplicationService(
                                    created = '2015-07-07T15:49:51.230+02:00', 
                                    id = '123', 
                                    name = '0', 
                                    org_id = '0', 
                                    hostname = 'db.example.com', 
                                    ipv4_addresses = [
                                        '192.0.2.1'
                                        ], 
                                    name_resolution = 'static', 
                                    port = 56, 
                                    protocol = 'tcp', 
                                    assignments = [
                                        agilicus_api.models.application_service_assignment.ApplicationServiceAssignment(
                                            app_id = '0', 
                                            environment_name = '0', 
                                            org_id = '0', )
                                        ], 
                                    updated = '2015-07-07T15:49:51.230+02:00', 
                                    service_type = 'vpn', 
                                    service_protocol_type = 'ip', 
                                    connector_id = '123', )
                                ], 
                            file_share_services = [
                                agilicus_api.models.file_share_service.FileShareService(
                                    metadata = {"id":"ac233asaksjfF","created":"2017-07-07T15:49:51.230+00:00","updated":"2020-01-27T12:19:46.430+00:00"}, 
                                    spec = agilicus_api.models.file_share_service_spec.FileShareServiceSpec(
                                        name = 'share1', 
                                        share_name = 'share1', 
                                        org_id = '123', 
                                        local_path = '/home/agilicus/public/share1', 
                                        connector_id = '123', ), 
                                    status = agilicus_api.models.file_share_service_status.FileShareServiceStatus(
                                        share_base_app_name = '0', 
                                        instance_id = 'asdas9Gk4asdaTH', 
                                        instance_org_id = '39ddfGAaslts8qX', ), )
                                ], )
                        ], ), 
                stats = agilicus_api.models.agent_connector_stats.AgentConnectorStats(
                    system = agilicus_api.models.agent_connector_system_stats.AgentConnectorSystemStats(
                        os_version = 'Linux 5.4.0-45-generic #49-Ubuntu SMP Wed Aug 26 13:38:52 UTC 2020 x86_64 GNU/Linux', 
                        os_uptime = 45232, 
                        agent_uptime = 45000, 
                        agent_version = 'v0.29.5 8e4fe7281219aa02dcc088154b7e7e3fc279f259', 
                        agent_release_train = 'stable', 
                        agent_connector_id = 'SdaAs93adflq3a', 
                        agent_connector_org_id = 'd0d4laSDr4ws9', ), 
                    metadata = agilicus_api.models.agent_connector_stats_metadata.AgentConnectorStatsMetadata(
                        creation_time = '2020-07-07T15:40:46.010Z', 
                        collection_time = '2020-07-07T15:49:51.230Z', 
                        receipt_time = '2020-07-07T15:49:51.530Z', ), 
                    transport = agilicus_api.models.agent_connector_transport_stats.AgentConnectorTransportStats(
                        active_connections = 32, 
                        target_number_connections = 32, 
                        connection_start_count = 64, 
                        connection_stop_count = 32, ), 
                    shares = agilicus_api.models.agent_connector_share_stats.AgentConnectorShareStats(
                        exposed_shares_count = 2, 
                        server_running = True, 
                        server_start_time = '2020-07-07T15:55:51.230Z', 
                        server_stop_time = '2020-07-07T15:55:51.230Z', 
                        server_start_count = 2, 
                        server_stop_count = 1, 
                        per_share_info = [
                            agilicus_api.models.agent_connector_per_share_stats.AgentConnectorPerShareStats(
                                share_prefix = '/public', 
                                share_id = '5s930sdfsdlA', 
                                local_path = '/home/user/shared', 
                                total_requests = 5132, 
                                successful_requests = 5102, 
                                failed_requests = 30, 
                                bytes_sent = 30458101, 
                                bytes_received = 9574339, 
                                share_start_time = '2020-07-07T15:55:52.230Z', )
                            ], ), 
                    overall_status = 'good', )
            )
        else :
            return AgentConnectorStatus(
        )

    def testAgentConnectorStatus(self):
        """Test AgentConnectorStatus"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
